pub struct SnKeyDatabase { /* private fields */ }Expand description
Storage for digests of escrowed events.
The digest of an escrowed event can be used to retrieve the full event from the LogDatabase.
The storage is indexed by a tuple of (identifier, sn), with the value being the event’s digest.