pub struct InceptionEvent {
pub key_config: KeyConfig,
pub witness_config: InceptionWitnessConfig,
pub inception_configuration: Vec<String>,
pub data: Vec<Seal>,
}Expand description
Inception Event
Describes the inception (icp) event data,
Fields
key_config: KeyConfigwitness_config: InceptionWitnessConfiginception_configuration: Vec<String>data: Vec<Seal>Implementations
Sourceimpl InceptionEvent
impl InceptionEvent
pub fn new( key_config: KeyConfig, witness_config: Option<InceptionWitnessConfig>, inception_config: Option<Vec<String>>, ) -> Self
Sourcepub fn incept_self_addressing(
self,
derivation: HashFunction,
format: SerializationFormats,
) -> Result<KeriEvent<KeyEvent>, Error>
pub fn incept_self_addressing( self, derivation: HashFunction, format: SerializationFormats, ) -> Result<KeriEvent<KeyEvent>, Error>
Incept Self Addressing
Takes the inception data and creates an EventMessage based on it, with using the given format and deriving a Self Addressing Identifier with the given derivation method