pub struct KeyConfig {
pub threshold: SignatureThreshold,
pub public_keys: Vec<BasicPrefix>,
pub next_keys_data: NextKeysData,
}Fields
threshold: SignatureThresholdpublic_keys: Vec<BasicPrefix>next_keys_data: NextKeysDataImplementations
Sourceimpl KeyConfig
impl KeyConfig
pub fn new( public_keys: Vec<BasicPrefix>, next_keys_data: NextKeysData, threshold: Option<SignatureThreshold>, ) -> Self
Sourcepub fn verify(
&self,
message: &[u8],
sigs: &[IndexedSignature],
) -> Result<bool, SignatureError>
pub fn verify( &self, message: &[u8], sigs: &[IndexedSignature], ) -> Result<bool, SignatureError>
Verify
Verifies the given sigs against the given message using the KeyConfigs Public Keys, according to the indexes in the sigs.
Sourcepub fn verify_next(&self, next: &KeyConfig) -> Result<bool, SignatureError>
pub fn verify_next(&self, next: &KeyConfig) -> Result<bool, SignatureError>
Verify Next
Verifies that the given next KeyConfig matches that which is committed to in next_keys_data of this KeyConfig
Sourcepub fn commit(&self, derivation: &HashFunction) -> NextKeysData
pub fn commit(&self, derivation: &HashFunction) -> NextKeysData
Serialize For Next
Serializes the KeyConfig for creation or verification of a threshold key digest commitment